@@ -56,6 +56,7 @@ time_t ApplicationTools::startTime;
 size_t ApplicationTools::terminalWidth = 80;
 float ApplicationTools::terminalSplit = 0.5;
 bool ApplicationTools::interactive = true;
+int ApplicationTools::warningLevel = 0;
 
 /******************************************************************************/
 
@@ -65,18 +66,102 @@ bool ApplicationTools::parameterExists(
 {
   return (params.find(parameterName) != params.end() && !TextTools::isEmpty(params[parameterName]));
 }
+
+bool ApplicationTools::parameterExists(
+  const std::string & parameterName,
+  std::vector<std::string>& params)
+{
+  for (size_t i = 0; i < params.size(); ++i)
+    if (params[i] == parameterName)
+      return true;
+
+  return false;
+}
+
+/******************************************************************************/
   
+std::vector<std::string> ApplicationTools::matchingParameters(const std::string& pattern, std::map<std::string, std::string>& params)
+{
+  vector<string> retv;
+
+  map<string, string>::iterator it;
+  for (it=params.begin(); it!=params.end(); it++)
+  {
+    StringTokenizer stj(pattern, "*", true, false);
+    size_t pos1, pos2;
+    string parn = it->first;
+    bool flag(true);
+    string g = stj.nextToken();
+    pos1 = parn.find(g);
+    if (pos1 != 0)
+      flag = false;
+    pos1 += g.length();
+    while (flag && stj.hasMoreToken())
+      {
+        g = stj.nextToken();
+        pos2 = parn.find(g, pos1);
+        if (pos2 == string::npos)
+          {
+            flag = false;
+            break;
+          }
+        pos1 = pos2 + g.length();
+      }
+    if (flag &&
+        ((g.length() == 0) || (pos1 == parn.length()) || (parn.rfind(g) == parn.length() - g.length())))
+      retv.push_back(parn);
+  }
+
+  return retv;
+}
+
+std::vector<std::string> ApplicationTools::matchingParameters(const std::string& pattern, std::vector<std::string>& params)
+{
+  vector<string> retv;
+
+  for (size_t i=0;i<params.size();i++)
+  {
+    StringTokenizer stj(pattern, "*", true, false);
+    size_t pos1, pos2;
+    string parn = params[i];
+    bool flag(true);
+    string g = stj.nextToken();
+    pos1 = parn.find(g);
+    if (pos1 != 0)
+      flag = false;
+    pos1 += g.length();
+    while (flag && stj.hasMoreToken())
+    {
+      g = stj.nextToken();
+      pos2 = parn.find(g, pos1);
+      if (pos2 == string::npos)
+      {
+        flag = false;
+        break;
+      }
+      pos1 = pos2 + g.length();
+    }
+    if (flag &&
+        ((g.length() == 0) || (pos1 == parn.length()) || (parn.rfind(g) == parn.length() - g.length())))
+      retv.push_back(parn);
+  }
+
+  return retv;
+}
+
 /******************************************************************************/
 
-std::string ApplicationTools::getAFilePath(
-  const std::string& parameter,
-  std::map<std::string, std::string>& params,
+string ApplicationTools::getAFilePath(
+  const string& parameter,
+  map<string, string>& params,
   bool isRequired,
   bool mustExist,
-  const std::string& suffix,
-  bool suffixIsOptional) throw (Exception)
+  const string& suffix,
+  bool suffixIsOptional,
+  const string& defaultPath, 
+  int warn) throw (Exception)
 {
-  string filePath = getStringParameter(parameter, params, "none", suffix, suffixIsOptional, false);
+  string filePath = getStringParameter(parameter, params, defaultPath, suffix, suffixIsOptional, warn);
   if (filePath == "") filePath = "none";
   if (filePath == "none" && isRequired)
   {
@@ -93,12 +178,12 @@ std::string ApplicationTools::getAFilePath(
 /******************************************************************************/
 
 double ApplicationTools::getDoubleParameter(
-  const std::string & parameterName,
-  std::map<std::string, std::string> & params,
+  const std::string& parameterName,
+  std::map<std::string, std::string>& params,
   double defaultValue,
-  const std::string & suffix,
+  const std::string& suffix,
   bool suffixIsOptional,
-  bool warn)
+  int warn)
 {
   double dParam = defaultValue;
   if (parameterExists(parameterName + suffix, params))
@@ -109,7 +194,7 @@ double ApplicationTools::getDoubleParameter(
   {
     dParam = TextTools::toDouble(params[parameterName]);
   }
-  else if(warn)
+  else if(warn <= warningLevel)
   {
     displayWarning("Parameter " + parameterName + suffix + " not specified. Default used instead: " + TextTools::toString(defaultValue));
   }
@@ -124,14 +209,14 @@ int ApplicationTools::getIntParameter(
   int defaultValue,
   const std::string & suffix,
   bool suffixIsOptional,
-  bool warn)
+  int warn)
 {
   int iParam = defaultValue;
   if (parameterExists(parameterName + suffix, params)) {
     iParam = TextTools::toInt(params[parameterName + suffix]);
   } else if(suffixIsOptional && parameterExists(parameterName, params)) {
     iParam = TextTools::toInt(params[parameterName]);
-  } else if (warn) {
+  } else if (warn <= warningLevel) {
     displayWarning("Parameter " + parameterName + suffix + " not specified. Default used instead: " + TextTools::toString(defaultValue));
   }
   return iParam;
@@ -145,14 +230,14 @@ std::string ApplicationTools::getStringParameter(
   const std::string& defaultValue,
   const std::string& suffix,
   bool suffixIsOptional,
-  bool warn)
+  int warn)
 {
   string sParam = defaultValue;
   if (parameterExists(parameterName + suffix, params)) {
     sParam = params[parameterName + suffix];
   } else if (suffixIsOptional && parameterExists(parameterName, params)) {
     sParam = params[parameterName];
-  } else if (warn) {
+  } else if (warn <= warningLevel) {
     displayWarning("Parameter " + parameterName + " not specified. Default used instead: " + defaultValue);
   }
   return sParam;
@@ -166,7 +251,7 @@ bool ApplicationTools::getBooleanParameter(
   bool defaultValue,
   const std::string& suffix,
   bool suffixIsOptional,
-  bool warn)
+  int warn)
 {
   string sParam;
   bool bParam = defaultValue;
@@ -179,7 +264,7 @@ bool ApplicationTools::getBooleanParameter(
     sParam = params[parameterName];
   }
   else {
-    if (warn)
+    if (warn <= warningLevel)
     {
       displayWarning("Parameter " + parameterName + " not specified. Default used instead: " + TextTools::toString(defaultValue));
     }
@@ -239,14 +324,15 @@ void ApplicationTools::displayGauge(size_t iter, size_t total, char symbol, cons
   size_t width = static_cast<size_t>(static_cast<float>(terminalWidth) * terminalSplit - 2);
   string gauge = string(static_cast<size_t>((1. * static_cast<double>(iter) / static_cast<double>(total)) * static_cast<double>(width)), symbol);
   string info = mes;
+  size_t step = static_cast<size_t>(ceil(1. * static_cast<double>(total) / static_cast<double>(width)));
+  size_t x = iter % step;
   if (interactive)
   {
     string fill = string(width - gauge.length(), ' ');
     gauge = "[" + gauge + fill + "] " + TextTools::resizeLeft(TextTools::toString(100 * iter / total), 3) + "%";
     if (mes.size() > terminalWidth - gauge.size())
       info = TextTools::resizeRight(mes, terminalWidth - gauge.size());
-    *message << '\r' + info + gauge;
-    message->flush();
+    if (x == 0 || iter == total) { *message << '\r' + info + gauge; message->flush(); }
   }
   else
   {
@@ -256,7 +342,6 @@ void ApplicationTools::displayGauge(size_t iter, size_t total, char symbol, cons
       message->flush();
       return;
     }
-    size_t step = static_cast<size_t>(ceil(1. * static_cast<double>(total) / static_cast<double>(width)));
     if (iter >= total)
     {
       size_t fill = static_cast<size_t>(static_cast<float>(terminalWidth) * terminalSplit) - (total - 1) / step - 1;
@@ -264,7 +349,6 @@ void ApplicationTools::displayGauge(size_t iter, size_t total, char symbol, cons
       message->flush();
       return;
     }
-    size_t x = iter % step;
     if (x == 0) { *message << symbol; message->flush(); }
   }
 }
