@@ -1,5 +1,5 @@
 //
-// File: BppStream.h
+// File: OutputStream.h
 // Created by: Julien Dutheil
 // Created on: Mon Jan 25 17:41 2010
 //
@@ -37,8 +37,8 @@ The fact that you are presently reading this means that you have had
 knowledge of the CeCILL license and that you accept its terms.
 */
 
-#ifndef _BPPSTREAM_H_
-#define _BPPSTREAM_H_
+#ifndef _OUTPUTSTREAM_H_
+#define _OUTPUTSTREAM_H_
 
 #include "../Clonable.h"
 
@@ -77,8 +77,8 @@ public:
   virtual OutputStream& operator<<(const bool& message) = 0;
   virtual OutputStream& endLine() = 0;
   virtual OutputStream& flush() = 0;
-  virtual OutputStream& setPrecision(unsigned int digit) = 0;
-  virtual unsigned int getPrecision() const = 0;
+  virtual OutputStream& setPrecision(int digit) = 0;
+  virtual int getPrecision() const = 0;
   virtual OutputStream& enableScientificNotation(bool yn) = 0;
   virtual bool isScientificNotationEnabled() const = 0;
 
@@ -105,19 +105,19 @@ class AbstractOutputStream :
   public virtual OutputStream
 {
 private:
-  unsigned int precision_;
+  int precision_;
   bool scienceNotation_;
 
 public:
   AbstractOutputStream() : precision_(6), scienceNotation_(false) {}
 
 public:
-  OutputStream& setPrecision(unsigned int digit)
+  OutputStream& setPrecision(int digit)
   {
     precision_ = digit;
     return *this;
   }
-  unsigned int getPrecision() const { return precision_; }
+  int getPrecision() const { return precision_; }
 
   virtual OutputStream& enableScientificNotation(bool yn) { scienceNotation_ = yn; return *this; }
   virtual bool isScientificNotationEnabled() const { return scienceNotation_; }
@@ -350,5 +350,5 @@ public:
 
 } // end of namespace bpp;
 
-#endif //_BPPSTREAM_H_
+#endif //_OUTPUTSTREAM_H_
 
