@@ -116,10 +116,12 @@ throw (ParameterNotFoundException, Exception)
 
   string id = "__alias_" + p2 + "_to_" + p1;
   string idCheck = "__alias_" + p1 + "_to_" + p2;
+
   if (aliasListenersRegister_.find(idCheck) != aliasListenersRegister_.end())
     throw Exception("AbstractParameterAliasable::aliasParameters. Trying to alias parameter " + p2 + " to " + p1 + ", but parameter " + p1 + " is already aliased to parameter " + p2 + ".");
   Parameter* param1 = &getParameter_(p1);
   Parameter* param2 = &getParameter_(p2);
+
   if (!param1->hasConstraint())
   {
     if (param2->hasConstraint())
@@ -127,19 +129,72 @@ throw (ParameterNotFoundException, Exception)
   }
   else
   // We use a small trick here, we test the constraints on the basis of their string description (C++ does not provide a default operator==() :( ).
-  if (param2->hasConstraint() && (param1->getConstraint()->getDescription() != param2->getConstraint()->getDescription()))
-    throw Exception("AbstractParameterAliasable::aliasParameters. Cannot alias parameter " + p2 + " to " + p1 + ", because the constraints attached to these two parameters are different.");
+    if (param2->hasConstraint() && (param1->getConstraint()->getDescription() != param2->getConstraint()->getDescription()))
+      throw Exception("AbstractParameterAliasable::aliasParameters. Cannot alias parameter " + p2 + " to " + p1 + ", because the constraints attached to these two parameters are different.");
 
   // Every thing seems ok, let's create the listener and register it:
-  AliasParameterListener* aliasListener = new AliasParameterListener(id, getParameters().whichParameterHasName(getNamespace() + p2), &getParameters_());
+
+  AliasParameterListener* aliasListener = new AliasParameterListener(id, getParameters().whichParameterHasName(getNamespace() + p2), &getParameters_(), p1);
+
+  ParameterList pl=getParameters_();
+  
   aliasListenersRegister_[id] = aliasListener;
+
   // Now we add it to the appropriate parameter, that is p1.
   // The parameter will not own the listener, the bookkeeping being achieved by the register:
   param1->addParameterListener(aliasListener, false);
   // Finally we remove p2 from the list of independent parameters:
   independentParameters_.deleteParameter(getNamespace() + p2);
+
 }
 
+void AbstractParameterAliasable::aliasParameters(map<string, string>& unparsedParams, bool verbose)
+{
+  ParameterList plpars, pl=getParameters();
+    
+  for (size_t i=0; i< pl.size(); i++)
+  {
+    if (unparsedParams.find(pl[i].getName())==unparsedParams.end())
+      plpars.addParameter(*pl[i].clone());
+  }
+
+  size_t unp_s=unparsedParams.size();  
+  while (unp_s!=0)
+  {
+    map<string, string>::iterator it;
+    for (it=unparsedParams.begin(); it!=unparsedParams.end(); it++)
+    {
+      Parameter* pp=0;
+      try {
+        pp=&plpars.getParameter(it->second);
+      }
+      catch (ParameterNotFoundException& e){
+        if (!pl.hasParameter(it->second))
+          throw ParameterNotFoundException("Unknown aliasing parameter", it->second);
+        continue;
+      }
+      auto_ptr<Parameter> p2(pp->clone());
+      p2->setName(it->first);
+      plpars.addParameter(p2.release());
+      plpars.getParameter(it->first);
+      aliasParameters(it->second, it->first);
+      if (verbose)
+        ApplicationTools::displayResult("Parameter alias found", it->first + " -> " + it->second + " = " + TextTools::toString(pp->getValue()));
+      unparsedParams.erase(it);
+    }
+
+    if (unparsedParams.size()==unp_s)
+      throw Exception("Error, there is a cycle in aliasing");
+    else
+      unp_s=unparsedParams.size();
+  }
+
+  matchParametersValues(plpars);
+}
+
+  
+
+
 void AbstractParameterAliasable::unaliasParameters(const std::string& p1, const std::string& p2)
 throw (ParameterNotFoundException, Exception)
 {
@@ -190,18 +245,79 @@ void AbstractParameterAliasable::setNamespace(const std::string& prefix)
 vector<string> AbstractParameterAliasable::getAlias(const string& name) const
 {
   vector<string> aliases;
+
   for (map<string, AliasParameterListener*>::const_iterator it = aliasListenersRegister_.begin();
        it != aliasListenersRegister_.end();
        it++)
   {
-    if (it->second->getName() == name)
+    if (it->second->getFrom() == name)
     {
       string alias = it->second->getAlias();
       aliases.push_back(alias);
-      vector<string> chainAliases = getAlias(alias);
-      VectorTools::append(aliases, chainAliases);
+      if (alias!=name){
+        vector<string> chainAliases = getAlias(alias);
+        VectorTools::append(aliases, chainAliases);
+      }
     }
   }
   return aliases;
 }
 
+ParameterList AbstractParameterAliasable::getAliasedParameters(const ParameterList& pl) const
+{
+  ParameterList aliases;
+  bool b=false;
+  
+  for (map<string, AliasParameterListener*>::const_iterator it = aliasListenersRegister_.begin();
+       it != aliasListenersRegister_.end();
+       it++)
+  {
+    if ((pl.hasParameter(it->second->getFrom()) ||
+         aliases.hasParameter(it->second->getFrom()))
+        && ! (aliases.hasParameter(it->second->getAlias()) ||
+              pl.hasParameter(it->second->getAlias())))
+    {
+      b=true;
+      aliases.addParameter(getParameter(it->second->getAlias()));
+    }
+  }
+  
+  while (b)
+  {
+    b=false;
+    
+    for (map<string, AliasParameterListener*>::const_iterator it = aliasListenersRegister_.begin();
+         it != aliasListenersRegister_.end();
+         it++)
+    {
+      if (aliases.hasParameter(it->second->getFrom())
+          && ! (aliases.hasParameter(it->second->getAlias()) ||
+                pl.hasParameter(it->second->getAlias())))
+      {
+        b=true;
+        aliases.addParameter(getParameter(it->second->getAlias()));
+      }
+    }
+  }
+  
+  return aliases;
+}
+
+string AbstractParameterAliasable::getFrom(const string& name) const
+{
+  string from="";
+  
+  for (map<string, AliasParameterListener*>::const_iterator it = aliasListenersRegister_.begin();
+       it != aliasListenersRegister_.end();
+       it++)
+    {
+      if (it->second->getName() == name)
+        {
+          from = it->second->getFrom();
+          break;
+        }
+    }
+
+  return from;
+}
+
