@@ -5,7 +5,7 @@
 //
 
 /*
-   Copyright or © or Copr. Julien Dutheil, (November 19, 2004)
+   Copyright or © or Copr. Bio++ Development Team, (November 19, 2004)
 
    This software is a computer program whose purpose is to provide classes
    for numerical calculus.
@@ -38,6 +38,7 @@
  */
 
 #include "ParameterList.h"
+#include "../Text/StringTokenizer.h"
 
 using namespace bpp;
 
@@ -184,6 +185,40 @@ std::vector<std::string> ParameterList::getParameterNames() const
   return pNames;
 }
 
+/****************************************************************************/
+
+vector<string> ParameterList::getMatchingParameterNames(const string& pattern) const
+{
+  vector<string> pNames;
+  for (unsigned int i = 0; i < size(); i++)
+    {
+      string name = parameters_[i]->getName();
+
+      StringTokenizer stj(pattern, "*", true, false);
+      size_t pos1, pos2;
+      bool flag(true);
+      string g=stj.nextToken();
+      pos1=name.find(g);
+      if (pos1!=0)
+        flag=false;
+      pos1+=g.length();
+      while (flag && stj.hasMoreToken()){
+        g=stj.nextToken();
+        pos2=name.find(g,pos1);
+        if (pos2 == string::npos){
+          flag=false;
+          break;
+        }
+        pos1=pos2+g.length();
+      }
+      if (flag &&
+          ((g.length()==0) || (pos1==name.length()) || (name.rfind(g)==name.length()-g.length())))
+        pNames.push_back(name);
+    }
+
+  return pNames;
+}
+
 /******************************************************************************/
 
 void ParameterList::addParameter(const Parameter& param) throw (ParameterException)
@@ -325,7 +360,7 @@ bool ParameterList::testParametersValues(const ParameterList& params) const
 
 /******************************************************************************/
 
-bool ParameterList::matchParametersValues(const ParameterList& params)
+bool ParameterList::matchParametersValues(const ParameterList& params, vector<size_t>* updatedParameters)
 throw (ConstraintException)
 {
   // First we check if all values are correct:
@@ -342,15 +377,20 @@ throw (ConstraintException)
   // If all values are ok, we set them:
   bool ch = 0;
 
+  size_t pos = 0;
   for (vector<Parameter*>::const_iterator it = params.parameters_.begin(); it < params.parameters_.end(); it++)
   {
     if (hasParameter((*it)->getName()))
     {
       Parameter* p = &getParameter((*it)->getName());
-      if (p->getValue() != (*it)->getValue())
+      if (p->getValue() != (*it)->getValue()) {
         ch |= 1;
-      p->setValue((*it)->getValue());
+        p->setValue((*it)->getValue());
+        if (updatedParameters)
+          updatedParameters->push_back(pos);
+      }
     }
+    pos++;
   }
   return ch;
 }
@@ -419,11 +459,21 @@ void ParameterList::deleteParameter(const std::string& name) throw (ParameterNot
 }
 
 /******************************************************************************/
-void ParameterList::deleteParameters(const std::vector<std::string>& names) throw (ParameterNotFoundException)
+void ParameterList::deleteParameters(const std::vector<std::string>& names, bool mustExist) throw (ParameterNotFoundException)
 {
   for (unsigned int i = 0; i < names.size(); i++)
   {
-    deleteParameter(names[i]);
+    try
+    {
+      deleteParameter(names[i]);
+    }
+    catch (ParameterNotFoundException& e)
+    {
+      if (mustExist)
+        throw ParameterNotFoundException(e);
+      else
+        continue;
+    }
   }
 }
 
@@ -433,7 +483,7 @@ void ParameterList::deleteParameter(size_t index) throw (IndexOutOfBoundsExcepti
   if (index >= size()) throw IndexOutOfBoundsException("ParameterList::deleteParameter.", index, 0, size());
   Parameter* p = parameters_[index];
   delete p;
-  parameters_.erase(parameters_.begin() + index);
+  parameters_.erase(parameters_.begin() + static_cast<ptrdiff_t>(index));
 }
 
 /******************************************************************************/
@@ -447,7 +497,7 @@ void ParameterList::deleteParameters(const std::vector<size_t>& indices) throw (
     if (index >= size()) throw IndexOutOfBoundsException("ParameterList::deleteParameter.", index, 0, size());
     Parameter* p = parameters_[index];
     delete p;
-    parameters_.erase(parameters_.begin() + index);
+    parameters_.erase(parameters_.begin() + static_cast<ptrdiff_t>(index));
   }
 }
 
