@@ -45,81 +45,131 @@
 using namespace bpp;
 using namespace std;
 
-Simplex::Simplex(const std::vector<double>& probas, unsigned short method, const std::string& name) : AbstractParameterAliasable(name),
+Simplex::Simplex(const std::vector<double>& probas, unsigned short method, bool allowNull, const std::string& name) : AbstractParameterAliasable(name),
   dim_(probas.size()),
   method_(method),
   vProb_(),
   valpha_()
 {
+  if  (dim_==0)
+    return;
+
   double sum = VectorTools::sum(probas);
   if (fabs(1. - sum) > NumConstants::SMALL())
     throw Exception("Simplex. Probabilities must equal 1 (sum =" + TextTools::toString(sum) + ").");
 
+  const Constraint* pc = (allowNull ? &Parameter::PROP_CONSTRAINT_IN : &Parameter::PROP_CONSTRAINT_EX);
+
   for (unsigned int i = 0; i < dim_; i++)
   {
     vProb_.push_back(probas[i]);
   }
 
+  double y = 1;
   switch (method_)
   {
+  case 1:
+    for (unsigned int i = 0; i < dim_ - 1; i++)
+    {
+      addParameter_(new Parameter(name + "theta" + TextTools::toString(i + 1), vProb_[i] / y, pc));
+      y -= vProb_[i];
+    }
+    break;
   case 2:
     for (unsigned int i = 0; i < dim_ - 1; i++)
     {
-      addParameter_(new Parameter(name + "theta" + TextTools::toString(i + 1), vProb_[i] / (vProb_[i] + vProb_[i + 1]), &Parameter::PROP_CONSTRAINT_IN));
+      addParameter_(new Parameter(name + "theta" + TextTools::toString(i + 1), vProb_[i] / (vProb_[i] + vProb_[i + 1]), pc));
     }
     for (unsigned int i = 0; i < dim_ - 1; i++)
     {
       valpha_.push_back(vProb_[i + 1] / vProb_[i]);
     }
     break;
-  case 1:
-    double y = 1;
-    for (unsigned int i = 0; i < dim_ - 1; i++)
+  case 3:
+    for (size_t i = 1; i < dim_; i++)
     {
-      addParameter_(new Parameter(name + "theta" + TextTools::toString(i + 1), vProb_[i] / y, &Parameter::PROP_CONSTRAINT_IN));
-      y -= vProb_[i];
+      size_t o = i;
+      size_t li2 = 0; // rank of the strongest bit
+      while (o)
+      {
+        li2++;
+        o = o >> 1;
+      }
+
+      double i1 = 0, i0 = 0;
+      size_t j = 0;
+      size_t pi = i &  ~(1 << (li2 - 1));
+      while (j < dim_)
+      {
+        size_t t = (j << li2) + pi;
+        if (t >= dim_)
+          break;
+        else
+          i0 += vProb_[t];
+        t += (1 << (li2 - 1));
+        if (t < dim_)
+          i1 += vProb_[t];
+        j++;
+      }
+      addParameter_(new Parameter(name + "theta" + TextTools::toString(i), i1 / (i0 + i1), pc));
     }
     break;
   }
 }
 
-Simplex::Simplex(size_t dim, unsigned short method, const std::string& name) :
+Simplex::Simplex(size_t dim, unsigned short method, bool allowNull, const std::string& name) :
   AbstractParameterAliasable(name),
   dim_(dim),
   method_(method),
   vProb_(),
   valpha_()
 {
+  if  (dim_==0)
+    return;
+  
   for (size_t i = 0; i < dim_; i++)
   {
     vProb_.push_back(1. / static_cast<double>(dim_));
   }
 
+  const Constraint* pc = (allowNull ? &Parameter::PROP_CONSTRAINT_IN : &Parameter::PROP_CONSTRAINT_EX);
+
+  double y = 1;
   switch (method_)
   {
+  case 1:
+    for (unsigned int i = 0; i < dim_ - 1; i++)
+    {
+      addParameter_(new Parameter(name + "theta" + TextTools::toString(i + 1), vProb_[i] / y, pc));
+      y -= vProb_[i];
+    }
+    break;
   case 2:
     for (unsigned int i = 0; i < dim_ - 1; i++)
     {
-      addParameter_(new Parameter(name+ "theta" + TextTools::toString(i + 1), 0.5, &Parameter::PROP_CONSTRAINT_IN));
+      addParameter_(new Parameter(name + "theta" + TextTools::toString(i + 1), 0.5, pc));
     }
     for (unsigned int i = 0; i < dim_ - 1; i++)
     {
       valpha_.push_back(1.);
     }
     break;
-  case 1:
-    double y = 1;
+  case 3:
     for (unsigned int i = 0; i < dim_ - 1; i++)
     {
-      addParameter_(new Parameter(name+"theta" + TextTools::toString(i + 1), vProb_[i] / y, &Parameter::PROP_CONSTRAINT_IN));
-      y -= vProb_[i];
+      addParameter_(new Parameter(name + "theta" + TextTools::toString(i + 1), 0.5, pc));
     }
+    setFrequencies(vProb_);
+    
     break;
   }
 }
 
 void Simplex::fireParameterChanged(const ParameterList& parameters)
 {
+  if  (dim_==0)
+    return;
+
   AbstractParameterAliasable::fireParameterChanged(parameters);
 
   double x = 1.0;
@@ -151,8 +201,37 @@ void Simplex::fireParameterChanged(const ParameterList& parameters)
       x += vProb_[i + 1];
     }
     for (unsigned int i = 0; i < dim_; i++)
+    {
       vProb_[i] /= x;
+    }
 
+    break;
+  case 3:
+    size_t o = dim_;
+    size_t ld2 = 0; // rank of the strongest bit
+    while (o)
+    {
+      ld2++;
+      o = o >> 1;
+    }
+    for (size_t i = 0; i < dim_; i++)
+    {
+      x = 1;
+      size_t ld = ld2;
+      size_t k = i;
+      while (ld)
+      {
+        if (k >> (ld - 1))
+          x *= getParameterValue("theta" + TextTools::toString(k));
+        else
+        {
+          if ((k + (1 << (ld - 1))) < dim_)
+            x *= 1 - getParameterValue("theta" + TextTools::toString(k + (1 << (ld - 1))));
+        }
+        k &= ~(1 << (--ld));
+      }
+      vProb_[i] = x;
+    }
     break;
   }
 }
@@ -160,6 +239,9 @@ void Simplex::fireParameterChanged(const ParameterList& parameters)
 
 void Simplex::setFrequencies(const std::vector<double>& probas)
 {
+  if  (dim_==0)
+    return;
+
   double sum = VectorTools::sum(probas);
   if (fabs(1. - sum) > NumConstants::SMALL())
     throw Exception("Simplex::setFrequencies. Probabilities must equal 1 (sum =" + TextTools::toString(sum) + ").");
@@ -168,22 +250,51 @@ void Simplex::setFrequencies(const std::vector<double>& probas)
 
   ParameterList pl;
   switch (method_)
+  {
+  case 1:
+    for (unsigned int i = 0; i < dim_ - 1; i++)
     {
-    case 1:
-      for (unsigned int i = 0; i < dim_ - 1; i++)
-        {
-          pl.addParameter(Parameter(getNamespace()+"theta" + TextTools::toString(i + 1), probas[i] / y));
-          y -= probas[i];
-        }
-      break;
-    case 2:
-      for (unsigned int i = 0; i < dim_ - 1; i++)
-        {
-          pl.addParameter(Parameter(getNamespace()+"theta" + TextTools::toString(i + 1), probas[i] / (probas[i] + probas[i + 1])));
-          valpha_[i]=probas[i + 1] / probas[i];
-        }
-      break;
+      pl.addParameter(Parameter(getNamespace() + "theta" + TextTools::toString(i + 1), probas[i] / y));
+      y -= probas[i];
     }
+    break;
+  case 2:
+    for (unsigned int i = 0; i < dim_ - 1; i++)
+    {
+      pl.addParameter(Parameter(getNamespace() + "theta" + TextTools::toString(i + 1), probas[i] / (probas[i] + probas[i + 1])));
+      valpha_[i] = probas[i + 1] / probas[i];
+    }
+    break;
+  case 3:
+    for (size_t i = 1; i < dim_; i++)
+    {
+      size_t o = i;
+      size_t li2 = 0; // rank of the strongest bit
+      while (o)
+      {
+        li2++;
+        o = o >> 1;
+      }
+
+      double i1 = 0, i0 = 0;
+      size_t j = 0;
+      size_t pi = i &  ~(1 << (li2 - 1));
+      while (j < dim_)
+      {
+        size_t t = (j << li2) + pi;
+        if (t >= dim_)
+          break;
+        else
+          i0 += vProb_[t];
+        t += (1 << (li2 - 1));
+        if (t < dim_)
+          i1 += vProb_[t];
+        j++;
+      }
+      pl.addParameter(Parameter(getNamespace() + "theta" + TextTools::toString(i), i1 / (i0 + i1)));
+    }
+    break;
+  }
 
   matchParametersValues(pl);
 }
