@@ -117,7 +117,10 @@ namespace bpp
      * @param entry Max number to reach.
      * @param generator Random number generator to use.
      */
-    static int giveIntRandomNumberBetweenZeroAndEntry(int entry, const RandomFactory& generator = *DEFAULT_GENERATOR);
+    template<class intType>
+    static intType giveIntRandomNumberBetweenZeroAndEntry(intType entry, const RandomFactory& generator = *DEFAULT_GENERATOR) {
+      return static_cast<intType>(giveRandomNumberBetweenZeroAndEntry(static_cast<double>(entry), generator));
+    }
 
     /**
      * @brief Set the default generator seed.
@@ -155,7 +158,6 @@ namespace bpp
      * @param beta The beta parameter.
      * @param generator The uniform generator to use.
      */
-
     static double randBeta(double alpha, double beta, const RandomFactory& generator = *DEFAULT_GENERATOR);
   
     /**
@@ -181,7 +183,7 @@ namespace bpp
     static T pickOne(std::vector<T>& v, bool replace = false) throw (EmptyVectorException<T>) {
       if (v.empty())
         throw EmptyVectorException<T>("RandomTools::pickOne: input vector is empty", &v);
-      size_t pos = static_cast<size_t>(RandomTools::giveIntRandomNumberBetweenZeroAndEntry(static_cast<int>(v.size())));
+      size_t pos = RandomTools::giveIntRandomNumberBetweenZeroAndEntry<size_t>(v.size());
       if (replace)
         return v[pos];
       else {
@@ -192,6 +194,14 @@ namespace bpp
       }
     }
 
+   template<class T>
+    static T pickOne(const std::vector<T>& v) throw (EmptyVectorException<T>) {
+      if (v.empty())
+        throw EmptyVectorException<T>("RandomTools::pickOne: input vector is empty", &v);
+      size_t pos = RandomTools::giveIntRandomNumberBetweenZeroAndEntry<size_t>(v.size());
+      return v[pos];
+    }
+
     /**
      * @brief Sample a vector.
      *
@@ -273,7 +283,7 @@ namespace bpp
      * the result is a shuffle of the original vector.
      *
      * It has to be noted that in case of sampling without replacement,
-     * the effect of the weighting scheme will be lower as the sampe size becomes
+     * the effect of the weighting scheme will be weaker as the sample size becomes
      * close to the population size. In case the two are equal (pure permutations),
      * the weigths have no effect at all.
      *
@@ -285,7 +295,8 @@ namespace bpp
      * @throw IndexOutOfBoundException if the sample size exceeds the original
      * size when sampling without replacement.
      * @throw EmptyVectorException if the vector is empty.
-     *
+     * @warning: For large sampling with replacement, the function is not efficient,
+     * as it recomputes the some of weights for each element picked.
      * @author Julien Dutheil
      */
    template<class T> 
