@@ -5,7 +5,7 @@
 //
 
 /*
-Copyright or © or Copr. CNRS, (November 19, 2004)
+Copyright or © or Copr. Bio++ Development Team, (November 19, 2004)
 
 This software is a computer program whose purpose is to provide classes
 for numerical calculus.
@@ -195,7 +195,7 @@ class RTransformedParameter:
  * @f[
  * x' = s\tan\left(\pi\frac{x-a}{b-a} - \frac{\pi}{2}\right)
  * @f]
- * The 'a' and 'b' parameters are the lower and upper bounds and 's' is a sclaing factor set to 1 by default.
+ * The 'a' and 'b' parameters are the lower and upper bounds and 's' is a scaling factor set to 1 by default.
  * If the hyperbolic option is set to true (the default), then the following transformation is used instead:
  * @f[
  * x' = s\,\text{atanh}\left(2\frac{x-a}{b-a} - 1\right)
@@ -221,7 +221,7 @@ class IntervalTransformedParameter:
      * @param lowerBound the inerval lower bound to use.
      * @param upperBound the inerval lower bound to use.
      * @param scale the scaling factor.
-     * @param hyper tell if the hyberboic function should be used (true by default).
+     * @param hyper tell if the hyberbolic function should be used (true by default).
      */
     IntervalTransformedParameter(const std::string& name, double value, double lowerBound = 0, double upperBound = 1, double scale = 1, bool hyper = true):
       TransformedParameter(name, hyper ?
@@ -242,7 +242,7 @@ class IntervalTransformedParameter:
       if (value <= lowerBound_ || value >= upperBound_) throw ConstraintException("IntervalTransformedParameter::setValue", this, value);
       setValue(hyper_ ?
           scale_ * atanh(2. * (value - lowerBound_) / (upperBound_ - lowerBound_) - 1.) :
-          scale_ * tan(NumConstants::PI() * (value - lowerBound_)/(upperBound_ - lowerBound_) - NumConstants::PI() / 2.));
+          scale_ * std::tan(NumConstants::PI() * (value - lowerBound_)/(upperBound_ - lowerBound_) - NumConstants::PI() / 2.));
     }
 
     double getOriginalValue() const
@@ -259,7 +259,7 @@ class IntervalTransformedParameter:
     {
       double x = getValue();
       double x2 = hyper_ ?
-        1. / (cosh(pow(x / scale_, 2))) * (upperBound_ - lowerBound_) / (2. * scale_) :
+        1. / (pow(cosh(x / scale_), 2)) * (upperBound_ - lowerBound_) / (2. * scale_) :
         (upperBound_ - lowerBound_) / (NumConstants::PI() * scale_ * (pow(x / scale_, 2) + 1.));
       return x2;
     }
@@ -267,7 +267,7 @@ class IntervalTransformedParameter:
     {
       double x = getValue();
       double x2 = hyper_ ?
-        - 1. / (cosh(pow(x / scale_, 2))) * tanh(x / scale_) *(upperBound_ - lowerBound_) / (scale_ * scale_) :
+        - 1. / (pow(cosh(x / scale_), 2)) * tanh(x / scale_) * (upperBound_ - lowerBound_) / (scale_ * scale_) :
         -2. * x * (upperBound_ - lowerBound_) / (NumConstants::PI() * pow(scale_, 3) * pow((pow(x / scale_, 2) + 1.), 2));
       return x2;
     }
