@@ -215,6 +215,9 @@ bool TextTools::isDecimalNumber(char c)
 
 bool TextTools::isDecimalNumber(const std::string& s, char dec, char scientificNotation)
 {
+  if (isEmpty(s))
+    return false;
+              
   size_t sepCount = 0;
   size_t sciCount = 0;
   size_t i = 0;
@@ -228,7 +231,7 @@ bool TextTools::isDecimalNumber(const std::string& s, char dec, char scientificN
       sciCount++;
       if (i == s.size() - 1) return false; //Must be sthg after scientific notation.
       c = s[i + 1];
-      if (c == '-') i++;
+      if (c == '-' || c == '+') i++;
       if (i == s.size() - 1) return false; //Must be sthg after scientific notation.
       if (sepCount == 0) sepCount = 1; //We do not want any dec in the exponent.
     } else if (!isDecimalNumber(c))
@@ -243,6 +246,9 @@ bool TextTools::isDecimalNumber(const std::string& s, char dec, char scientificN
 
 bool TextTools::isDecimalInteger(const std::string& s, char scientificNotation)
 {
+  if (isEmpty(s))
+    return false;
+              
   size_t sciCount = 0;
   size_t i = 0;
   if (s[0] == '-') i = 1;
@@ -254,6 +260,8 @@ bool TextTools::isDecimalInteger(const std::string& s, char scientificNotation)
       if (i == s.size() - 1) return false; //Must be sthg after scientific notation.
       c = s[i + 1];
       if (c == '-') return false; //Not an integer then!
+      if (c == '+') i++;
+      if (i == s.size() - 1) return false; //Must be sthg after scientific notation.
     } else if (!isDecimalNumber(c))
       return false;
     if (sciCount > 1)
@@ -291,9 +299,9 @@ std::string TextTools::toString(double d, int precision)
 
 /******************************************************************************/
 
-int TextTools::toInt(const std::string& s) throw (Exception)
+int TextTools::toInt(const std::string& s, char scientificNotation) throw (Exception)
 {
-  if (!isDecimalInteger(s)) throw Exception("TextTools::toInt(). Invalid number specification: " + s);
+  if (!isDecimalInteger(s, scientificNotation)) throw Exception("TextTools::toInt(). Invalid number specification: " + s);
   istringstream iss(s);
   int i;
   iss >> i;
@@ -302,9 +310,9 @@ int TextTools::toInt(const std::string& s) throw (Exception)
 
 /******************************************************************************/
 
-double TextTools::toDouble(const std::string& s) throw (Exception)
+double TextTools::toDouble(const std::string& s, char dec, char scientificNotation) throw (Exception)
 {
-  if (!isDecimalNumber(s)) throw Exception("TextTools::toDouble(). Invalid number specification: " + s);
+  if (!isDecimalNumber(s, dec, scientificNotation)) throw Exception("TextTools::toDouble(). Invalid number specification: " + s);
   istringstream iss(s);
   double d;
   iss >> d;
@@ -353,8 +361,8 @@ throw (Exception)
 {
   string t = "";
   int blockCount = 0;
-  int begPos = 0;
-  for (unsigned int i = 0; i < s.size(); i++)
+  size_t begPos = 0;
+  for (size_t i = 0; i < s.size(); i++)
   {
     char current = s[i];
     if (current == blockBeginning)
@@ -512,12 +520,11 @@ void TextTools::replaceAll(std::string& target, const std::string& query, const
 {
   if (query.empty())
     return;
-  size_t pos = 0;
+  size_t pos = target.find(query);
   while (pos != string::npos) {
-    pos = target.find(query, pos);
     target.replace(pos, query.length(), replacement);
-    pos += replacement.length(); //We prevent recursivity!
-  
+    pos += replacement.length(); //We prevent recursivity! 
+    pos = target.find(query, pos);
   }
 }
 
